#!/bin/ksh
###############################################################################
#
#       Install new DataDirect ODBC Drivers
#
#       Module  Install_odbc.sh
#
#	Copyright IBM Corp. 2005, 2013
#
#       (c) Copyright 2002 Ascential Software. - All Rights Reserved
#       This is unpublished proprietary source code of Ascential Software.
#       The copyright notice above does not evidence any actual or intended
#       publication of such source code.
#	
#
#	This script installs a new set of DataDirect ODBC drivers
#	It will back up the following Directories/Files
#	branded_odbc 	--> branded_odbc_xxx
#	.odbcrel	--> odbcrel_xxx
#	(where xxx is the current installed version of the driver set)
#
#	The new branded_odbc directory is then copied into the
#	$/.dshome/.. directory
#	the new odbcrel file is copied to the $./dsome/.. directory
#	as .odbcrel
#
#	NOTE the .odbc.ini file in the $/.dshome directory is not
#	replaced the customer will have to modify the sample.odbc.ini
#	file to set their connect requirements.
#
#
#
###############################################################################
#
#       Maintenence log - insert most recent change descriptions at top
#
#	Date.... Request# WHO Description.........................................
#	29/11/13 WI187241 nikejain Update to detect current Odbc relase info during DataDirect ODBC Driver update.
#       19/11/13 WI186401 nikejain Adding 'p' switch with cp to preserve the original date-time stamp during installation.
#	18/12/09 00152835 QY  Remove dsadm check
#	07/04/09 00152835 QY  Updated default DSHOME path
#
#	09/09/05 10084	PS  IBM Blue wash
#	05/01/03 10084  PS  Added DSHOME check.
#	05/08/02 10080  PS  Added Ascential tools functionality
#	05/08/02 36889  PS  New.
###############################################################################
#
# Set datestamp

datestamp=`date '+%m%d%y.%H%M%S'`

# Get current working directory
	ODBC_PWD=`pwd`

# output log file that will be created
	ODBC_LOGFILE="$ODBC_PWD/odbc_log.txt.$datestamp"

# Print info about the log file we are about to create

	# output copyright message
	clear
	echo							
	echo "Install_odbc.sh"				
	echo "Copyright IBM Corp. 2005, 2012"	
	echo							
	sleep 5
	echo "\nCreating log file $ODBC_LOGFILE..."

#	Record a time stamp
	echo "\nTimestamp : `date`\n" > $ODBC_LOGFILE

#	Get info about the user's system and version
	echo "\n*** System information\n" >> $ODBC_LOGFILE
	echo "\nuname  : `uname -a`" >>  $ODBC_LOGFILE
	echo "\nuptime :`uptime`" >> $ODBC_LOGFILE

#	Get information about the current user
	echo "\n*** User information" >>  $ODBC_LOGFILE
	ODBC_USERID=`who am i | cut -d" " -f1 `
	ODBC_GROUPS=`groups $ODBC_USERID`

	echo "\nUser    : $ODBC_USERID" >> $ODBC_LOGFILE
	echo "Groups  : $ODBC_GROUPS" >>  $ODBC_LOGFILE 
	echo "umask   : `umask`" >> $ODBC_LOGFILE

# Get new odbc relese level

	NEW_ODBC_REL=`cat branded_odbc/IBM_Tools/odbcrel`

	echo "\nNew odbc release is  : $NEW_ODBC_REL" | tee -a $ODBC_LOGFILE

#	Get the DataStage Home Diectory & cd to the DstaStage directory

	DSHOME=`cat /.dshome`
	if [[ $DSHOME = "" ]]
	then
		echo "\n\nDSHOME not set, please enter the DSHOME path e.g"
		echo "/opt/IBM/InformationServer/Server/DSEngine\n"
		read DSHOME
	fi
	echo "\nDataStage home is  : $DSHOME" | tee -a $ODBC_LOGFILE
	cd $DSHOME/..


#	Get current odbc release number

	ODBC_REL=`cat ./branded_odbc/IBM_Tools/odbcrel`
	echo "\nCurrent odbc release is  : $ODBC_REL" | tee -a $ODBC_LOGFILE

	echo "\nRenaming branded_odbc directory to branded_odbc_$ODBC_REL.$datestamp" | tee -a $ODBC_LOGFILE

	mv branded_odbc branded_odbc_$ODBC_REL.$datestamp

	echo "\nCopying new Drivers..." | tee -a $ODBC_LOGFILE

	cp -pr $ODBC_PWD/branded_odbc .

	echo "Copying new Driver release file..." | tee -a $ODBC_LOGFILE
	
	cp -r $ODBC_PWD/branded_odbc/IBM_Tools/odbcrel ./branded_odbc/.odbcrel

	echo "\n*** Your IBM OEM ODBC Drivers have been updated to $NEW_ODBC_REL ***" | tee -a $ODBC_LOGFILE	
	echo "*** Please refer to the sample.odbc.ini for changes to your .odbc.ini file ***" | tee -a $ODBC_LOGFILE
	echo "Install details can be found in:-\n log file $ODBC_LOGFILE"
	echo "\n[Done...]"| tee -a $ODBC_LOGFILE


